@@ -30,7 +30,7 @@ class ProductGroupAdmin(InstrumentModelAdmin):
                     ("type", "category", "umbrella"),
                     ("management_company", "depositary", "transfer_agent", "administrator"),
                     ("investment_manager", "auditor", "paying_agent"),
-                    ("net_asset_value_computation_method_path", "risk_scale"),
+                    ("net_asset_value_computation_method_path", "order_routing_custodian_adapter", "risk_scale"),
                 )
             },
         ),
