@@ -21,6 +21,7 @@ from .product_groups import ProductGroupFactory, ProductGroupRepresentantFactory
 from .products import IndexProductFactory, ProductFactory, WhiteLabelProductFactory, ModelPortfolioWithBaseProductFactory
 from .reconciliations import AccountReconciliationFactory, AccountReconciliationLineFactory
 from .roles import ManagerPortfolioRoleFactory, ProductPortfolioRoleFactory
-from .trades import CustomerTradeFactory, TradeFactory, TradeProposalFactory
+from .trades import CustomerTradeFactory, TradeFactory
+from .orders import OrderProposalFactory, OrderFactory
 from .indexes import IndexFactory
 from .rebalancing import (RebalancingModelFactory, RebalancerFactory)
