@@ -127,7 +127,7 @@ class AssetPositionFilter(wb_filters.FilterSet):
     )
 
     underlying_instrument__is_cash = wb_filters.BooleanFilter(
-        label="With Cash", exclude=True, lookup_expr="exact", field_name="underlying_instrument__is_cash"
+        label="Cash", lookup_expr="exact", method="filter_is_cash"
     )
     underlying_instrument__instrument_type = wb_filters.ModelChoiceFilter(
         label="Instrument Type",
@@ -230,6 +230,13 @@ class AssetPositionFilter(wb_filters.FilterSet):
             return queryset.filter(underlying_instrument__in=value.get_classified_instruments())
         return queryset
 
+    def filter_is_cash(self, queryset, name, value):
+        if value is True:
+            return queryset.filter(Q(underlying_quote__is_cash=True) | Q(underlying_quote__is_cash_equivalent=True))
+        if value is False:
+            return queryset.filter(Q(underlying_quote__is_cash=False) & Q(underlying_quote__is_cash_equivalent=False))
+        return queryset
+
     def filter_portfolio_instrument(self, queryset, name, value):
         if value:
             return queryset.filter(
