@@ -1,3 +1,5 @@
+from datetime import date, timedelta
+
 from wbcore import filters as wb_filters
 from wbfdm.models import Instrument
 
@@ -16,6 +18,24 @@ class PortfolioFilterSet(wb_filters.FilterSet):
         filter_params={"is_managed": True},
         method="filter_instrument",
     )
+    modeled_after = wb_filters.ModelChoiceFilter(
+        label="Modeled After",
+        queryset=Portfolio.objects.all(),
+        endpoint=Portfolio.get_representation_endpoint(),
+        value_key=Portfolio.get_representation_value_key(),
+        label_key=Portfolio.get_representation_label_key(),
+        method="filter_modeled_after",
+    )
+
+    def filter_modeled_after(self, queryset, name, value):
+        if value:
+            modeled_after_portfolio_ids = list(
+                map(
+                    lambda p: p.portfolio.id, value.get_model_portfolio_relationships(date.today() - timedelta(days=7))
+                )
+            )
+            return queryset.filter(id__in=modeled_after_portfolio_ids)
+        return queryset
 
     def filter_instrument(self, queryset, name, value):
         if value:
