@@ -9,7 +9,8 @@ from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from wbcore.contrib.authentication.authentication import User
 from wbcore.contrib.currency.import_export.handlers import CurrencyImportHandler
-from wbcore.contrib.io.exceptions import DeserializationError
+from wbcore.contrib.currency.models import Currency
+from wbcore.contrib.io.exceptions import DeserializationError, SkipImportError
 from wbcore.contrib.io.imports import ImportExportHandler
 from wbcore.contrib.notifications.dispatch import send_notification
 from wbfdm.import_export.handlers.instrument import InstrumentImportHandler
@@ -36,9 +37,13 @@ class AssetPositionImportHandler(ImportExportHandler):
         portfolio_data = data.pop("portfolio", None)
         underlying_quote_data = data.pop("underlying_quote", data.pop("underlying_instrument", None))
         if "currency" in data:
-            data["currency"] = self.currency_handler.process_object(
-                data["currency"], read_only=True, raise_exception=False
-            )[0]
+            currency = self.currency_handler.process_object(data["currency"], read_only=True, raise_exception=False)[0]
+            # we do not support GBX in our instrument table
+            if currency.key == "GBX":
+                currency = Currency.objects.get(key="GBP")
+                if "initial_price" in data:
+                    data["initial_price"] /= 1000
+            data["currency"] = currency
         data["date"] = datetime.strptime(data["date"], "%Y-%m-%d").date()
         if data.get("asset_valuation_date", None):
             data["asset_valuation_date"] = datetime.strptime(data["asset_valuation_date"], "%Y-%m-%d").date()
@@ -83,6 +88,9 @@ class AssetPositionImportHandler(ImportExportHandler):
             if not (value := data.get(field, None)) is None:
                 data[field] = Decimal(value)
 
+        if data["weighting"] == 0:
+            raise SkipImportError("exclude position whose weight is 0")
+
     def _process_raw_data(self, data: Dict[str, Any]):
         if prices := data.get("prices", None):
             self.import_source.log += "Instrument Prices found: Importing"
