@@ -82,7 +82,7 @@ def parse(import_source):
     cash = (
         df.loc[
             cash_mask,
-            ["currency__key", "initial_currency_fx_rate", "portfolio", "date", "initial_price", "initial_shares"],
+            ["currency__key", "initial_currency_fx_rate", "portfolio", "date", "initial_shares"],
         ]
         .groupby(
             [
@@ -94,21 +94,20 @@ def parse(import_source):
         .agg(
             {
                 "initial_currency_fx_rate": "mean",
-                "initial_price": "mean",
                 "initial_shares": "sum",
             }
         )
         .reset_index()
     ).copy()
     cash["underlying_quote"] = cash["currency__key"].apply(lambda x: {"currency__key": x, "instrument_type": "cash"})
-
+    cash["initial_price"] = 1.0
     # cash_equivalents_mask, all asset type code that match TRES and which don't have accounting category T111
     cash_equivalents_mask = df["Asset type code"].str.match("TRES") & ~df["Accounting category"].str.match("T111")
 
     cash_equivalents = (
         df.loc[
             cash_equivalents_mask,
-            ["currency__key", "initial_currency_fx_rate", "portfolio", "date", "initial_price", "initial_shares"],
+            ["currency__key", "initial_currency_fx_rate", "portfolio", "date", "initial_shares"],
         ]
         .groupby(
             [
@@ -120,7 +119,6 @@ def parse(import_source):
         .agg(
             {
                 "initial_currency_fx_rate": "mean",
-                "initial_price": "mean",
                 "initial_shares": "sum",
             }
         )
@@ -129,9 +127,11 @@ def parse(import_source):
     cash_equivalents["underlying_quote"] = cash_equivalents["currency__key"].apply(
         lambda x: {"currency__key": x, "instrument_type": "cash_equivalent"}
     )
+    cash_equivalents["initial_price"] = 1.0
 
     # equities = df.loc[df["Accounting category"].str.match("010"), :].copy() # Historically, we filter out equity base on the "accounting category" that matches "010", we had issue with equity having the code "020". We decided to use the column "Asset type code" and filter out with the code "VCOM"
     equities = df.loc[df["Asset type code"].str.match("VMOB"), :].copy()
+
     if not equities.empty:
         equities["underlying_quote"] = equities.apply(lambda x: get_underlying_quote(x), axis=1)
         equities["exchange"] = equities.apply(lambda x: get_exchange(x), axis=1)
@@ -140,7 +140,6 @@ def parse(import_source):
         del equities["Bloom Ticker"]
         del equities["Asset description"]
     df = pd.concat([cash, equities, cash_equivalents])
-
     df["asset_valuation_date"] = df["date"]
     # Rename the columns
 
