@@ -10,7 +10,10 @@ def parse(import_source):
     with suppress(KeyError):
         series_data = json.loads(import_source.file.read())["payload"]["series"]
         for series in series_data:
-            isin = series["item"]["priceIdentifier"]
+            try:
+                isin = series["key"]["priceIdentifier"]
+            except KeyError:
+                isin = series["priceIdentifier"]
             if Product.objects.filter(isin=isin).exists():  # ensure the timeseries contain data for products we handle
                 for point in series["points"]:
                     data.append(
