@@ -1,4 +1,4 @@
-from collections import defaultdict
+import logging
 from contextlib import suppress
 from datetime import date
 from decimal import Decimal, InvalidOperation
@@ -30,7 +30,6 @@ from pandas._libs.tslibs.offsets import BDay
 from wbcore.contrib.currency.models import Currency, CurrencyFXRates
 from wbcore.contrib.io.mixins import ImportMixin
 from wbcore.signals import pre_merge
-from wbcore.utils.enum import ChoiceEnum
 from wbfdm.models import Classification, ClassificationGroup, Instrument
 from wbfdm.models.instruments.instrument_prices import InstrumentPrice
 from wbfdm.signals import add_instrument_to_investable_universe
@@ -43,6 +42,8 @@ from wbportfolio.models.portfolio_relationship import (
 from wbportfolio.models.roles import PortfolioRole
 from wbportfolio.pms.typing import Position as PositionDTO
 
+logger = logging.getLogger("pms")
+
 MARKETCAP_S = 2_000_000_000
 MARKETCAP_M = 10_000_000_000
 MARKETCAP_L = 50_000_000_000
@@ -55,145 +56,7 @@ HOUR = MINUTE * 60
 DAY = HOUR * 24
 
 if TYPE_CHECKING:
-    from wbportfolio.models.portfolio import Portfolio
-
-
-class AssetPositionIterator:
-    """
-    Efficiently converts position data into AssetPosition models with batch operations
-    and proper dependency management.
-
-    Features:
-    - Bulk database fetching for performance
-    - Thread-safe operations
-    - Clear type hints
-    - Memory-efficient storage
-    """
-
-    positions: dict[tuple[date, int, int | None], "AssetPosition"]
-
-    _prices: dict[date, dict[int, float]]
-    _weights: dict[date, dict[int, float]]
-    _fx_rates: dict[date, dict[Currency, CurrencyFXRates]]
-    _instruments: dict[int, Instrument]
-
-    def __init__(
-        self,
-        portfolio: "Portfolio",
-        prices: dict[date, dict[int, float]] | None = None,
-        infer_underlying_quote_price: bool = False,
-    ):
-        self.portfolio = portfolio
-        self.infer_underlying_quote_price = infer_underlying_quote_price
-        # Initialize data stores with type hints
-        self._instruments = {}
-        self._fx_rates = defaultdict(dict)
-        self._weights = defaultdict(dict)
-        self._prices = prices or defaultdict(dict)
-        self.positions = dict()
-
-    def _get_instrument(self, instrument_id: int) -> Instrument:
-        try:
-            return self._instruments[instrument_id]
-        except KeyError:
-            instrument = Instrument.objects.get(id=instrument_id)
-            self._instruments[instrument_id] = instrument
-            return instrument
-
-    def _get_fx_rate(self, val_date: date, currency: Currency) -> CurrencyFXRates | None:
-        try:
-            return self._fx_rates[val_date][currency]
-        except KeyError:
-            with suppress(CurrencyFXRates.DoesNotExist):
-                fx_rate = CurrencyFXRates.objects.get(
-                    currency=currency, date=val_date
-                )  # we create a fx rate anyway to not fail the position. The fx rate expect to be there later on
-                self._fx_rates[val_date][currency] = fx_rate
-                return fx_rate
-
-    def _get_price(self, val_date: date, instrument: Instrument) -> float | None:
-        try:
-            return self._prices[val_date][instrument.id]
-        except KeyError:
-            return None
-
-    def _dict_to_model(self, val_date: date, instrument_id: int, weighting: float) -> "AssetPosition":
-        underlying_quote = self._get_instrument(instrument_id)
-        currency_fx_rate_portfolio_to_usd = self._get_fx_rate(val_date, self.portfolio.currency)
-        currency_fx_rate_instrument_to_usd = self._get_fx_rate(val_date, underlying_quote.currency)
-        price = self._get_price(val_date, underlying_quote)
-        position = AssetPosition(
-            underlying_quote=underlying_quote,
-            weighting=weighting,
-            date=val_date,
-            asset_valuation_date=val_date,
-            is_estimated=True,
-            portfolio=self.portfolio,
-            currency=underlying_quote.currency,
-            initial_price=price,
-            currency_fx_rate_portfolio_to_usd=currency_fx_rate_portfolio_to_usd,
-            currency_fx_rate_instrument_to_usd=currency_fx_rate_instrument_to_usd,
-            initial_currency_fx_rate=None,
-            underlying_quote_price=None,
-            underlying_instrument=None,
-        )
-        position.pre_save(
-            infer_underlying_quote_price=self.infer_underlying_quote_price
-        )  # inferring underlying quote price is potentially very slow for big dataset of positions, it's not very needed for model portfolio so we disable it
-        return position
-
-    def add(
-        self,
-        positions: list["AssetPosition"] | tuple[date, dict[int, float]],
-    ):
-        """
-        Add multiple positions efficiently with batch processing
-
-        Args:
-            positions: Iterable of AssetPosition instances or dictionary of weight {instrument_id: weight} that needs to be converted into AssetPosition
-        """
-        if isinstance(positions, tuple):
-            val_date = positions[0]
-            positions = [(val_date, i, w) for i, w in positions[1].items()]  # unflatten data to make it iterable
-        for position in positions:
-            if not isinstance(position, AssetPosition):
-                position = self._dict_to_model(*position)
-
-            # Generate unique composite key
-            key = (
-                position.date,
-                position.underlying_quote.id,
-                position.portfolio_created.id if position.portfolio_created else None,
-            )
-            # Merge duplicate positions
-            if existing_position := self.positions.get(key):
-                position.weighting += existing_position.weighting
-                position.initial_shares += existing_position.initial_shares
-            # ensure the position portfolio is the iterator portfolio (could be different when computing look-through for instance)
-            position.portfolio = self.portfolio
-            if position.initial_price is not None and position.initial_currency_fx_rate is not None:
-                self.positions[key] = position
-                self._weights[position.date][position.underlying_quote.id] = float(position.weighting)
-
-        return self
-
-    def get_dates(self) -> list[date]:
-        """Get sorted list of unique dates"""
-        return list(self._weights.keys())
-
-    def get_weights(self) -> dict[date, dict[int, float]]:
-        """Get weight structure with instrument IDs as keys"""
-        return dict(self._weights)
-
-    def __iter__(self):
-        # return an iterable excluding the position with a null weight if the portfolio is manageable (otherwise, we assume the 0-weight position is valid)
-        yield from filter(lambda a: not a.portfolio.is_manageable or a.weighting, self.positions.values())
-
-    def __getitem__(self, item: tuple[date, Instrument]) -> float:
-        return self._weights[item[0]][item[1].id]
-
-    def __bool__(self) -> bool:
-        return len(self.positions.keys()) > 0
+    pass
 
 
 class AssetPositionDefaultQueryset(QuerySet):
@@ -359,25 +222,12 @@ class AnalyticalAssetPositionManager(DefaultAssetPositionManager):
         )
 
 
-class AssetPositionGroupBy(ChoiceEnum):
-    INDUSTRY = "Industry"
-    COUNTRY = "Country"
-    CURRENCY = "Currency"
-    CASH = "Cash"
-    MARKET_CAPITALIZATION = "Market Cap"
-    LIQUIDITY = "Liquidity"
-
-    @classmethod
-    def get_class_method_group_by(cls, name: str):
-        _map = {
-            "INDUSTRY": "industry",
-            "COUNTRY": AssetPosition.country_group_by,
-            "CURRENCY": AssetPosition.currency_group_by,
-            "CASH": AssetPosition.cash_group_by,
-            "MARKET_CAPITALIZATION": AssetPosition.marketcap_group_by,
-            "LIQUIDITY": AssetPosition.liquidity_group_by,
-        }
-        return _map[name]
+class AssetPositionGroupBy(models.TextChoices):
+    INDUSTRY = "classification", "Industry"
+    INSTRUMENT_TYPE = "instrument_type", "Type"
+    COUNTRY = "country", "Country"
+    CURRENCY = "currency", "Currency"
+    CASH = "is_cash", "Cash"
 
 
 class AssetPosition(ImportMixin, models.Model):
@@ -464,8 +314,8 @@ class AssetPosition(ImportMixin, models.Model):
     # )
 
     weighting = models.DecimalField(
-        decimal_places=6,
-        max_digits=7,
+        decimal_places=8,
+        max_digits=9,
         default=Decimal(0),
         verbose_name="Weight",
         help_text="The Weight of the Asset on the price date of the Asset.",
@@ -584,7 +434,7 @@ class AssetPosition(ImportMixin, models.Model):
 
         if not getattr(self, "currency", None):
             self.currency = self.underlying_quote.currency
-        if not self.underlying_quote_price and infer_underlying_quote_price:
+        if not self.underlying_quote_price and (infer_underlying_quote_price or not self.initial_price):
             try:
                 # We get only the instrument price (and don't create it) because we don't want to create product instrument price on asset position propagation
                 # Instead, we decided to opt for a post_save based system that will assign the missing position price when a price is created
@@ -693,15 +543,15 @@ class AssetPosition(ImportMixin, models.Model):
     def get_portfolio_total_asset_value(self) -> Decimal:
         return self.portfolio.get_total_asset_value(self.date)
 
-    def _build_dto(self, new_weight: Decimal = None, **kwargs) -> PositionDTO:
+    def _build_dto(self, **kwargs) -> PositionDTO:
         """
         Data Transfer Object
         Returns:
             DTO position object
         """
-        return PositionDTO(
+        parameters = dict(
             underlying_instrument=self.underlying_quote.id,
-            weighting=self.weighting if new_weight is None else new_weight,
+            weighting=self.weighting,
             shares=self._shares,
             date=self.date,
             asset_valuation_date=self.asset_valuation_date,
@@ -726,8 +576,9 @@ class AssetPosition(ImportMixin, models.Model):
             price=self._price,
             currency_fx_rate=self._currency_fx_rate,
             portfolio_created=self.portfolio_created.id if self.portfolio_created else None,
-            **kwargs,
         )
+        parameters.update(kwargs)
+        return PositionDTO(**parameters)
 
     @cached_property
     @admin.display(description="Adjusting Factor (adjustment)")
