@@ -2,6 +2,8 @@ import numpy as np
 import pandas as pd
 from skfolio import Portfolio as BasePortfolio
 
+from .utils import fix_quantization_error
+
 
 class Portfolio(BasePortfolio):
     @property
@@ -16,21 +18,27 @@ class Portfolio(BasePortfolio):
         )
         return df
 
-    def get_next_weights(self) -> dict[int, float]:
+    def get_contributions(self) -> tuple[pd.Series, float]:
+        returns = self.X.iloc[-1, :].T
+        weights = self.all_weights_per_observation.iloc[-1, :].T
+        portfolio_returns = (weights * (returns + 1.0)).sum()
+        return returns, portfolio_returns
+
+    def get_next_weights(self, round_precision: int = 8) -> dict[int, float]:
         """
         Given the next returns, compute the drifted weights of this portfolio
-
+            round_precision: Round the weight to the given round number and ensure the total weight reflects this. Default to 8 decimals
         Returns:
             A dictionary of weights (instrument ids as keys and weights as values)
         """
-        returns = self.X.iloc[-1, :].T
+        returns, portfolio_returns = self.get_contributions()
         weights = self.all_weights_per_observation.iloc[-1, :].T
-        if weights.sum() != 0:
-            weights /= weights.sum()
-        contribution = weights * (returns + 1.0)
-        if contribution.sum() != 0:
-            contribution /= contribution.sum()
-        return contribution.dropna().to_dict()
+        next_weights = weights * (returns + 1.0) / portfolio_returns
+        next_weights = next_weights.dropna()
+        next_weights = next_weights / next_weights.sum()
+        if round_precision and not next_weights.empty:
+            next_weights = fix_quantization_error(next_weights, round_precision)
+        return {i: round(w, round_precision) for i, w in next_weights.items()}  # handle float precision manually
 
     def get_estimate_net_value(self, previous_net_asset_value: float) -> float:
         expected_returns = self.weights @ self.X.iloc[-1, :].T
