@@ -2,7 +2,7 @@ def register(model_name: str):
     """
     Decorator to include when a backend need automatic registration
     """
-    from wbportfolio.models.transactions.rebalancing import RebalancingModel
+    from wbportfolio.models.rebalancing import RebalancingModel
 
     def _decorator(backend_class):
         defaults = {
