@@ -15,9 +15,8 @@ from .products import ProductButtonConfig, ProductCustomerButtonConfig
 from .registers import RegisterButtonConfig
 from .trades import (
     TradeButtonConfig,
-    TradeInstrumentButtonConfig,
-    TradeTradeProposalButtonConfig
+    TradeInstrumentButtonConfig
 )
-from .trade_proposals import TradeProposalButtonConfig
+
 from .reconciliations import AccountReconciliationButtonViewConfig, AccountReconciliationLineButtonViewConfig
 from .signals import *
