@@ -11,7 +11,7 @@ class RebalancerDisplayConfig(DisplayViewConfig):
             fields=[
                 dp.Field(key="portfolio", label="Portfolio"),
                 dp.Field(key="rebalancing_model", label="Rebalancing Model"),
-                dp.Field(key="approve_trade_proposal_automatically", label="Approve automatically"),
+                dp.Field(key="apply_order_proposal_automatically", label="Approve automatically"),
                 dp.Field(key="frequency_repr", label="Frequency"),
                 dp.Field(key="activation_date", label="Activation Date"),
             ],
@@ -20,7 +20,7 @@ class RebalancerDisplayConfig(DisplayViewConfig):
     def get_instance_display(self) -> Display:
         return create_simple_display(
             [
-                ["rebalancing_model", "approve_trade_proposal_automatically"],
+                ["rebalancing_model", "apply_order_proposal_automatically"],
                 ["frequency", "activation_date"],
                 ["rebalancing_dates", "rebalancing_dates"],
             ]
